// Propagation linaire d'une impulsion brve
// Spectre gaussien
// Systme d'units : ps, THz et microns

exec('femto.sci');

// Paramtres
nPoints = 1024;
[nu,t] = ftAxis(nPoints,3000);
t_fs = 1000*t;
omega = (2*%pi)*nu;
speedLight = 300; // Vitesse de la lumire en microns par ps.
// Paramtres de l'impulsion
lambda0 = 0.8;    // Longueur d'onde centrale en microns
nu0 = speedLight/lambda0;  // Frquence centrale
omega0 = (2*%pi)*nu0;
deltaT = .005 / sqrt(8*log(2)); // 5 fs
field0_t = exp(-sqr(t)/4/sqr(deltaT)-%i*omega0*t);
field0 = ift(field0_t);

// Paramtres du matriau
nPhase = 1.453;
nGroupe = 1.467;
k0 = nPhase*omega0/speedLight;
k1 = nGroupe/speedLight;
k2 = 3.61E-8; // 361 fs2/cm ou 3.61E-8 ps2/um
// Paramtres de la simulation
zMax = 2000;   // distance de propagation (en microns)
z = 0:5:zMax; // Axe de propagation

map = zeros(length(z),nPoints); // carte |A(z,t)|^2

// Calcul du champ pour les valeurs successives de z
for iZ = 1:length(z) 
  phase0 = (k0-k1*omega0)*z(iZ);
  phase2 = 0.5*k2*z(iZ)*sqr(omega-omega0);
  phase = phase0 + phase2; // Pas de phase d'ordre 1 car on est dans le rfrentiel de l'impulsion
  field = field0 .*exp(%i*(phase0+phase2));
  field_t = ft(field);
  scf(1);       // Slection de la fentre n1
  drawlater();  // Ne pas dessiner tout de suite pour viter un clignotement de l'affichage
  clf();        // Effacer le graphe prcdent
  plot(t_fs,real(field_t)); // reprsentation du champ lectrique (en fs)
  xlim([-50 50]);       // Choix des bornes de l'axe des x
  ylim([-1 1]);         // Choix des bornes de l'axe des y
  xtitle(["z = " string(z(iZ)/1000) "mm "]);
  xlabel("Temps [fs]");
  ylabel("Champ lectrique");
  drawnow();    // Maintenant que c'est prt, on peut dessiner la figure
  map(iZ,:) = real(field_t); // Stockage du profil temporel
end;

// Reprsentation graphique de l'intensit temporelle le long de l'axe de propagation
scf(2); clf();
setColorMap(0);
grayplot(z,t_fs,map);
xlabel('z [microns]');
ylabel('t [fs]');
ylim([-50 50]);
xtitle('Propagation linaire d''une impulsion courte');
