// Interfromtrie spectrale par transforme de Fourier
// Traitement d'un spectre exprimental pour extraire la phase spectrale

exec('femto.sci');

// Paramtres
nPoints = 2048;
[nu,t] = ftAxis(nPoints,300);
t_fs = 1000*t;
omega = (2*%pi)*nu;
speedLight = 300000; // Vitesse de la lumire en nanomtres par ps.
// Paramtres de l'impulsion
lambda0 = 0.8;    // Longueur d'onde centrale en microns
nu0 = speedLight/lambda0;  // Frquence centrale
omega0 = (2*%pi)*nu0;
deltaT = .010 / sqrt(8*log(2)); // 10 fs

// data = csvread('CaF2.txt');
data = excel2sci('CaF2.txt',',');
lambda = data(:,1)';
spectre1 = data(:,2)';
spectre2 = data(:,3)';
nu = speedLight*inverse(lambda);

// Reprsentation graphique des spectres mesurs
scf(1);
clf();
plot(lambda,spectre1,'b');
plot(lambda,spectre2,'r');
xlim([700 900]);
ylim([0 2000]);
xlabel('Longueur d''onde [nm]');
ylabel('Intensit spectrale');
xtitle('Spectres mesurs sans et avec dispersion dans 4 cm de CaF2');


// Reprsentation graphique dans l'espace de Fourier
scf(2);
clf();
n = length(spectre1);
ksi = -n/2:n/2-1; // Axe des x aprs rotation
ft1 = ft(spectre1);
ft2 = ft(spectre2);
plot(ksi,abs(ft1)./max(abs(ft1)),'b');
plot(ksi,abs(ft2)./max(abs(ft2)),'r');
xlim([-500 500]);
xlabel('Pixel');
xtitle('Module de la transforme de Fourier du spectre');

// Fentrage pour ne conserver que le terme pertinent
fenetre = heaviside(ksi-50);
field1 = ift(ft1.*fenetre);
field2 = ift(ft2.*fenetre);
phase = unwrap(angle(field1))-unwrap(angle(field2));
scf(3);
clf();
plot(nu,phase);
xlim([300 430]);
xlabel('Frquence [THz]');
ylabel('Phase spectrale');

// Soustraction d'une phase linaire dtermine par calcul de la tangente
index = find( nu>370 & nu<390 ); // indices correspondant  l'intervalle [370,390]
index1 = index(length(index)/2); // indice du milieu
coefs = regress(nu(index),phase(index));
phase = phase - phase(index1) - coefs(2)*(nu-nu(index1));
// Reprsentation de la phase aprs soustraction de la pente linaire
scf(4);
clf();
plot(lambda,phase);
lambda_um = lambda/1000;
L = 40000; // Epaisseur de verre traverse en microns
phaseThe = 2*%pi*L*indice('CaF2',lambda_um)./lambda_um;
// Soustraction d'une phase linaire comme pour la phase mesure
coefs = regress(nu(index),phaseThe(index));
phaseThe = phaseThe - phaseThe(index1) - coefs(2)*(nu-nu(index1));
plot(lambda,phaseThe,'r');
xlim([700 900]);
ylim([0 60]);
xlabel('Longueur d''onde [nm]');
ylabel('Phase [rd]');
xtitle('Phase (mesure et calcule) pour 4 cm de CaF2');
