// Reprsentation de l'angle d'accord de phase pour le doublage de frquence
// et l'amplification paramtrique (OPA et NOPA)

exec('femto.sci');

// Fonction calculant l'angle theta pour que ne(theta) = n dans un cristal d'indices no et ne
function result = theta(n, no, ne)
  sinTheta = sqrt((n.^-2 - no.^-2)./(ne.^-2 - no.^-2));
  result = asin(sinTheta);
endfunction;

// Fonction calculant l'angle d'accord de phase en fonction de la longueur d'onde du fondamental
function result = thetaSHG(cristal,lambda) 
  lambda2 = lambda/2;
  [no1, ne1] = indice(cristal, lambda);
  [no2, ne2] = indice(cristal, lambda2);
  result = theta(no1,no2,ne2);
endfunction;

// Fonction calculant l'angle d'accord de phase pour un OPA
function result = thetaOPA(cristal, lambda_p, lambda_s)
  lambda_c = inverse(inverse(lambda_p)-inverse(lambda_s));
  [no_p, ne_p] = indice(cristal,lambda_p);
  [no_s, ne_s] = indice(cristal,lambda_s);
  [no_c, ne_c] = indice(cristal,lambda_c);
  n = lambda_p.*(no_s.*inverse(lambda_s)+no_c.*inverse(lambda_c));
  result = theta(n,no_p, ne_p);
endfunction;
  
// Fonction calculant l'angle d'accord de phase pour un NOPA
function result = thetaNOPA(cristal, alpha, lambda_p, lambda_s)
  lambda_c = inverse(inverse(lambda_p)-inverse(lambda_s));
  alpha_c = asin(lambda_c./lambda_s*sin(alpha));
  [no_p, ne_p] = indice(cristal,lambda_p);
  [no_s, ne_s] = indice(cristal,lambda_s);
  [no_c, ne_c] = indice(cristal,lambda_c);
  n = lambda_p.*(no_s.*inverse(lambda_s).*cos(alpha)+no_c.*inverse(lambda_c).*cos(alpha_c));
  result = theta(n,no_p,ne_p);
endfunction;

cristal = 'BBO';
// A choisir parmi la liste des cristaux dfinis dans la fonction indice de femto.sci.

lambda = .5:.01:1.5; 
lambda_nm = lambda*1000;

scf(1);
clf();
plot(lambda_nm,thetaSHG(cristal,lambda)*180/%pi);
xlabel('Longueur d''onde du fondamental [nm]');
ylabel('Angle d''accord de phase [] ');
xtitle('Doublage de frquence de type I');

scf(2);
clf();
plot(lambda_nm,thetaOPA(cristal,.4,lambda)*180/%pi);
xlabel('Longueur d''onde du signal [nm]');
ylabel('Angle d''accord de phase [] ');
xtitle('OPA pomp  400 nm (BBO)');

scf(3);
clf();
for alpha_deg = 0:1:4
  plot(lambda_nm,thetaNOPA(cristal,alpha_deg*%pi/180,.4,lambda)*180/%pi);
end;
plot(lambda_nm,thetaNOPA(cristal,3.7*%pi/180,.4,lambda)*180/%pi,'r');
xlabel('Longueur d''onde [nm]');
ylabel('Angle d''accord de phase [] ');
xtitle('NOPA pomp  400 nm (BBO)');
