// Reprsentation d'une impulsion femtoseconde
// Spectre gaussien
// Systme d'units : ps, THz et microns

exec('femto.sci');

// Paramtres
nPoints = 4096;
[nu,t] = ftAxis(nPoints,2000);
fs = .001;   // 1 fs exprime en ps
t_fs = t/fs; // Axe des temps en fs
omega = (2*%pi)*nu;
speedLight = 300000; // Vitesse de la lumire en nm par ps.
// Paramtres de l'impulsion
lambda0 = 800;    // Longueur d'onde centrale en nm
nu0 = speedLight/lambda0;  // Frquence centrale
omega0 = (2*%pi)*nu0;
deltaT = 5 * fs / sqrt(8*log(2)); // 10 fs
tau = -50*fs;
phi2 = 100*fs^2;
phi3 = 500*fs^3; 

field_t = exp(-sqr(t)/4/sqr(deltaT)).*exp(-%i*omega0*t);
field_nu = ift(field_t);

// Phase linaire
field_nu1 = field_nu.*exp(-%i*omega*tau); 
field_t1 = ft(field_nu1);
// Phase quadratique
field_nu2 = field_nu.*exp(%i*.5*phi2*(omega-omega0).^2);
field_t2 = ft(field_nu2);
// Phase cubique
field_nu3 = field_nu.*exp(%i*omega*tau+%i/6*phi3*(omega-omega0).^3);
field_t3 = ft(field_nu3);
legendString = ['phi1 = -50 fs' 'phi2 = 100 fs2' 'phi3 = 500 fs3'];

// Intensit temporelle
scf(1); clf();
plot(t_fs,sqr(abs(field_t1)));
plot(t_fs,sqr(abs(field_t2)),'r');
plot(t_fs,sqr(abs(field_t3)),'g');
xlim([-200 300]);
xlabel('Temps [fs]');
ylabel('Intensit temporelle');
xtitle('Impulsion gaussienne pour diverses phases spectrales');
legend(legendString);

// Champ lectrique
scf(2); clf();
plot(t_fs,real(field_t1));
plot(t_fs,real(field_t2),'r');
plot(t_fs,real(field_t3),'g');
xlim([-200 300]);
xlabel('Temps [fs]');
ylabel('Champ lectrique');
xtitle('Impulsion gaussienne pour diverses phases spectrales');
legend(legendString);

// Spectre
scf(3); clf();
plot(nu,sqr(abs(field_nu)));
xlim([300 450]);
xlabel('Frquence [THz]');
ylabel('Intensit spectrale');

// Spectre du champ doubl
scf(4); clf();
plot(nu,sqr(abs(ift(sqr(field_t1)))));
plot(nu,sqr(abs(ift(sqr(field_t2)))),'r');
plot(nu,sqr(abs(ift(sqr(field_t3)))),'g');
xlim([600 900]);
xlabel('Frquence [THz]');
ylabel('Intensit spectrale');
xtitle('Spectre doubl pour diverses phases spectrales');
legend(legendString);
